class GoldMatch extends xDeathMatch;

var globalconfig int CashPerKill;		// Base cash you start at for killing spree
var globalconfig float PerKillMultiplier; // Base cash killing spree formula uses Plus PerKillMultiplier% of this variable
var globalconfig int StartingGold;       // How much gold players have on spawning

var localized string GUIDisplayText[3]; // Config property label names
var localized string GUIDescText[3];    // Config property long descriptions

// We reward mass-murder with money, a new reality show?
function Killed( Controller Killer, Controller Killed, Pawn KilledPawn, class<DamageType> damageType )
{
	local GoldPickup Gold;
	local int KillingSpreeBonus;
	//local out int KillerGold, KilledGold;
	// Find out where our gold storage variables are on killer and killed player/bot
	if ( Killed != None )
	{
		log("Player made a kill");
		if ( Killer == none )
			log("Killer == none");
		if ( Killed == none )
			log("Killed == none");
		if ( KilledPawn == none )
			log("Killed == none");
		log("Killed Class: "$Killed.class);
		log("Killer Class: "$Killer.class);

		if ( Killer != None && Killer.bIsPlayer ) // Start of killing spree code
		{
			log("Killing Spree If Entered");
			if ( Killer.PlayerReplicationInfo.Kills > 2 )
			{ // We are on killing spree, free cash
				KillingSpreeBonus=CashPerKill+CashPerKill*(PerKillMultiplier*Killer.PlayerReplicationInfo.Kills);
				GoldController(Killer).PlayerGold+=KillingSpreeBonus;
				Killer.Pawn.ClientMessage("You received "$string(KillingSpreeBonus)$" gold bonus for killing "$string(Killer.PlayerReplicationInfo.Kills)$", a total of "$string(GoldController(Killer).PlayerGold), 'event');
			}
		} // End of killing spree code

		// Start of gold pickup drop code
		if ( Killed.Class == class'Gold.GoldController' )
		{
			if ( GoldController(Killed).PlayerGold <= 0 )
				return; // No gold to drop from Killed player, exit function
			log("Killed: Has Gold");
			Gold = Killed.Spawn(class'Gold.GoldPickup',,, Killed.Pawn.Location,);
			Gold.GoldAmmount = GoldController(Killed).PlayerGold;
		}
		else if ( Killed.Class == class'Gold.GoldAIController' )
		{
			if ( GoldAIController(Killed).PlayerGold <= 0 )
				return; // No gold to drop from Killed player, exit function
			log("Killed: Has Gold");
			Gold = Killed.Spawn(class'Gold.GoldPickup',,, Killed.Pawn.Location,);
			Gold.GoldAmmount = GoldAIController(Killed).PlayerGold;
		}
	}
	Super.Killed(Killer, Killed, KilledPawn, damageType);
}

function Bot SpawnBot(optional string botName)
{
	local Bot NewBot;
	local RosterEntry Chosen;
	local UnrealTeamInfo BotTeam;

	BotTeam = GetBotTeam();
	Chosen = BotTeam.ChooseBotClass(botName);

	if (Chosen.PawnClass == None)
		Chosen.Init(); //amb
	// log("Chose pawn class "$Chosen.PawnClass);
	//NewBot = Bot(Spawn(Chosen.PawnClass.default.ControllerClass));
	NewBot = Spawn(class'Gold.GoldAIController');
	//GoldAIController(NewBot).PlayerGold=StartingGold;
	//log("SpawnBot Gold: "$GoldAIController(NewBot).BotGold);
	if ( NewBot != None )
		InitializeBot(NewBot,BotTeam,Chosen);
	return NewBot;
}

function RestartPlayer( Controller aPlayer )
{
	if ( aPlayer != none )
	{
		if ( aPlayer.Class == class'Gold.GoldController' )
		{
			GoldController(aPlayer).PlayerGold=StartingGold;
			log("RestartPlayer; Player: Gold: "$GoldController(aPlayer).PlayerGold);
		}
		else if ( aPlayer.Class == class'Gold.GoldAIController' )
		{
			GoldAIController(aPlayer).PlayerGold=StartingGold;
			log("RestartPlayer; Bot: Gold: "$GoldAIController(aPlayer).PlayerGold);
		}
	}
	log("RestartPlayer: End");
	super.RestartPlayer(aPlayer);
}



// The function used to obtain the text that will be displayed within the
// config window.
static function string GetDisplayText(string PropName) {
	// The value of PropName passed to the function should match the variable name
	// being configured.
	switch (PropName)
	{
		case "StartingGold":  return default.GUIDisplayText[0];
		case "CashPerKill":  return default.GUIDisplayText[1];
		case "PerKillMultiplier": return default.GUIDescText[2];
	}
}

// The function used to obtain the "hint" text that is displayed at the bottom
// of the config window.
static event string GetDescriptionText(string PropName)
{
	// The value of PropName passed to the function should match the variable name
	// being configured.
	switch (PropName) {
		case "StartingGold":  return default.GUIDescText[0];
		case "CashPerKill":  return default.GUIDescText[1];
		case "PerKillMultiplier": return default.GUIDescText[2];
	}
	return Super.GetDescriptionText(PropName);
}

// This function is called to actually add the configuration options for the
// mutator to the configuration window.
static function FillPlayInfo(PlayInfo PlayInfo)
{
	super.FillPlayInfo(PlayInfo);  // Always begin with calling parent

	// The following function calls actually cause the configuration options to be
	// added to the mutator config window.  See below for a description of how to
	// use the PlayInfo.AddSetting() function.
	PlayInfo.AddSetting(default.GameGroup, "StartingGold", GetDisplayText("StartingGold"), 0, 2, "Text", "3;0:999");

	PlayInfo.AddSetting(default.GameGroup, "CashPerKill", GetDisplayText("CashPerKill"), 0, 0, "Text", "3;0:999");

	PlayInfo.AddSetting(default.GameGroup, "PerKillMultiplier", GetDisplayText("PerKillMultiplier"), 0, 0, "Text", "2;0.0:1.0");

	// Note that the second parameter, and the value passed to the GetDisplayText()
	// within the calls to the AddSetting() function above matches the
	// name of the attribute we want to configure as declared within the class defintion
}

defaultproperties
{
	Description="Free-for-all kill or be killed.  Earn gold to upgrade your character."
	GameName="Gold Match"
	Acronym="GM"
	DefaultPlayerClassName="Gold.GoldPawn"
	PlayerControllerClassName="Gold.GoldController"
	HUDType="Gold.GoldHud"
	StartingGold=100   // How much gold players have on spawning
	CashPerKill=50		// Base cash killing spree formula uses Plus PerKillMultiplier% of this variable
	PerKillMultiplier=0.5 // Percentage bonus per kill
	GUIDisplayText[0]="Gold At Spawn"
	GUIDisplayText[1]="Cash Per Kill"
	GUIDisplayText[2]="Bonus Per Kill"
	GUIDescText[0]="The ammount of gold players spawn with"
	GUIDescText[1]="Base cash per kill given for killing spree"
	GUIDescText[2]="Percentage bonus based on Cash Per Kill for each killing spree kill (decimal%, 0.0-1.0)"
}
